You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@lucene.apache.org by ds...@apache.org on 2018/11/26 15:11:28 UTC

lucene-solr:master: SOLR-5211: ignore temporarily pending moshe fixing

Repository: lucene-solr
Updated Branches:
  refs/heads/master a346ba0d3 -> dc134be44


SOLR-5211: ignore temporarily pending moshe fixing


Project: http://git-wip-us.apache.org/repos/asf/lucene-solr/repo
Commit: http://git-wip-us.apache.org/repos/asf/lucene-solr/commit/dc134be4
Tree: http://git-wip-us.apache.org/repos/asf/lucene-solr/tree/dc134be4
Diff: http://git-wip-us.apache.org/repos/asf/lucene-solr/diff/dc134be4

Branch: refs/heads/master
Commit: dc134be4499dfc1edd42941d6c6b1ff1b96190d3
Parents: a346ba0
Author: David Smiley <ds...@apache.org>
Authored: Mon Nov 26 10:11:21 2018 -0500
Committer: David Smiley <ds...@apache.org>
Committed: Mon Nov 26 10:11:21 2018 -0500

----------------------------------------------------------------------
 solr/core/src/test/org/apache/solr/update/RootFieldTest.java | 8 +++++---
 1 file changed, 5 insertions(+), 3 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/lucene-solr/blob/dc134be4/solr/core/src/test/org/apache/solr/update/RootFieldTest.java
----------------------------------------------------------------------
diff --git a/solr/core/src/test/org/apache/solr/update/RootFieldTest.java b/solr/core/src/test/org/apache/solr/update/RootFieldTest.java
index 7d4ed08..c9f6cfd 100644
--- a/solr/core/src/test/org/apache/solr/update/RootFieldTest.java
+++ b/solr/core/src/test/org/apache/solr/update/RootFieldTest.java
@@ -28,12 +28,14 @@ import org.apache.solr.common.SolrException;
 import org.apache.solr.common.SolrInputDocument;
 import org.apache.solr.common.params.CommonParams;
 import org.junit.BeforeClass;
+import org.junit.Ignore;
 import org.junit.Rule;
 import org.junit.Test;
 import org.junit.rules.ExpectedException;
 
 import static org.hamcrest.CoreMatchers.is;
 
+@Ignore("pending SOLR-5211 moshe fixing")
 public class RootFieldTest extends SolrJettyTestBase {
   private static boolean useRootSchema;
   private static final String MESSAGE = "Update handler should create and process _root_ field " +
@@ -49,8 +51,8 @@ public class RootFieldTest extends SolrJettyTestBase {
   @BeforeClass
   public static void beforeTest() throws Exception {
     useRootSchema = random().nextBoolean();
-    // schema.xml declares _root_ field while schema11.xml does not.
-    String schema = useRootSchema ? "schema.xml" : "schema11.xml";
+    // schema.xml declares _root_ field while schema15.xml does not.
+    String schema = useRootSchema ? "schema.xml" : "schema15.xml";
     initCore("solrconfig.xml", schema);
   }
 
@@ -78,7 +80,7 @@ public class RootFieldTest extends SolrJettyTestBase {
 
     // Check retrieved field values
     assertThat(foundDoc.getFieldValue( "id" ), is(docId));
-    assertThat( ((List)foundDoc.getFieldValue( "name" )).get(0), is("child free doc"));
+    assertThat(foundDoc.getFieldValue( "name" ), is("child free doc"));
 
     String expectedRootValue = expectRoot() ? docId : null;
     assertThat(MESSAGE, foundDoc.getFieldValue( "_root_" ), is(expectedRootValue));